@@ -1,16 +1,16 @@
 """
 Boticord API Wrapper
 ~~~~~~~~~~~~~~~~~~~
-A basic wrapper for the Boticord API.
+A basic wrapper for the BotiCord API.
 :copyright: (c) 2022 Marakarka
 :license: MIT, see LICENSE for more details.
 """
 
-__title__ = 'boticordpy'
-__author__ = 'Marakarka'
-__license__ = 'MIT'
-__copyright__ = 'Copyright 2022 Marakarka'
-__version__ = '2.0.3'
+__title__ = "boticordpy"
+__author__ = "Marakarka"
+__license__ = "MIT"
+__copyright__ = "Copyright 2022 Marakarka"
+__version__ = "2.2.0"
 
 from .client import BoticordClient
 from .webhook import Webhook
